# -*- coding: UTF-8 -*-

#
# Copyright (c) 2013-2023 NIBIO.
#
# This file is part of VIPSWeb 
# (see https://gitlab.nibio.no/VIPS/VIPSWeb).
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
#

## SAMPLE local_settings file. Copy to local_settings.py and configure as needed.
## Keep local_settings.py out of repository!! (already added to .gitignore)

## Settings for local instance of this application
## Change these for every new instance of the app
import os
# MUST be lazy, otherwise the app crashes
from django.utils.translation import gettext_lazy as _

DEBUG = True
MAINTENANCE_MODE = False

# Hosts/domain names that are valid for this site; required if DEBUG is False
# See https://docs.djangoproject.com/en/1.5/ref/settings/#allowed-hosts
ALLOWED_HOSTS = ["localhost"]

SITE_ROOT = os.path.dirname(os.path.realpath(__file__))

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/var/www/example.com/static/"
# Use 'python manage.py collectstatic' to put stuff into here
STATIC_ROOT = SITE_ROOT + '/../static/'

# Make this unique, and don't share it with anybody.
SECRET_KEY = '#### HIDDEN ###'

ADMINS = (
    ('Foo Bar', 'foobar@example.com'),
)

MANAGERS = ADMINS

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'en'
# List of available translations
AVAILABLE_LANGUAGES = ["en", "nb", "bg"]

# Preferred language in VIPSLogic (The backend for VIPSWeb)
VIPSLOGIC_LANGUAGE_CODE = "en"

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# In a Windows environment this must be set to your system time zone.
TIME_ZONE = 'Europe/Oslo'

# This can be used for testing purposes. Is valid locally for 
# this web page, not the VIPSLogic application. To simulate one year
# ago, set it to -12. Values > 0 make no sense, by the way.
SYSTEM_TIME_OFFSET_MONTHS = 0

# This is for testing purposes. It overrides SYSTEM_TIME_OFFSET_MONTHS
# It's valid locally for this web page, not the VIPSLogic application
# Ideally, they should be synchronized.  
# Valid values are None, "" or "%Y-%m-%d" 
# Example: SYSTEM_TIME_EXACT = "2019-06-15"
SYSTEM_TIME_EXACT = None

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
        'NAME': os.path.join(SITE_ROOT, 'default.sqlite3'),  # Or path to database file if using sqlite3.
        # The following settings are not used with sqlite3:
        'USER': '',
        'PASSWORD': '',
        'HOST': '',                      # Empty for localhost through domain sockets or '127.0.0.1' for localhost through TCP.
        'PORT': '',                      # Set to empty string for default.
    }
}

# Caching with memcached
# https://docs.djangoproject.com/en/3.2/topics/cache/
CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.memcached.PyMemcacheCache',
        'LOCATION': '127.0.0.1:11211',
    }
}

# Site name - appears in header of all pages. HTML is allowed
SITE_NAME = "Example site title"

# Insert Web Analytics Script?
# Could have more than 1
INSERT_WEB_ANALYTICS = False
WEB_ANALYTICS_SCRIPT = """
<!-- Plausible.io -->
<script defer data-domain="foo.bar.com" src="https://plausible.io/js/script.js"></script>
"""

# Convenience method for building URL to self
VIPSWEB_PROTOCOL = "https"

# The server hostname used for VIPSLogic
VIPSLOGIC_SERVER_NAME = "vipslogic"
# VIPSLogic protocol (http or https)
VIPSLOGIC_PROTOCOL = "http"
# This organization's ID in VIPSLogic/CoreManager
VIPS_ORGANIZATION_ID = 1
# If you want to include forecasts from several organizations
INCLUDE_ORGANIZATION_IDS =[1,2,3,4,5]
# Use this if you want to override and show icons for stations belonging to several organizations
#FORECAST_MAP_ORGANIZATION_IDS =[1,6]
# The server hostname used for VIPSCoreManager
VIPSCOREMANAGER_SERVER_NAME = "vipscoremanager"
# Local path to self signed certificate of VIPSCoreManager. 
# Set to none if using certificate signed by a CA
#VIPSCOREMANAGER_SSLCERT_PATH ="/path/to/myselfsignedcertificate.crt"
VIPSCOREMANAGER_SSLCERT_PATH = None
# Date format for dates from VIPSLogic
VIPSLOGIC_DATE_FORMAT = "%Y-%m-%d"

# Site owner info
SITE_OWNER_NAME = {"en":"FooBar Inc","nb":"ACME industrier"}
SITE_OWNER_URL = "http://www.example.com/"

# Grid models settings
WMS_SERVER_URL = "https://gridweb.vips.nibio.no/cgi-bin/"
AVAILABLE_GRID_MODELS = [
   {"model_id":"SEPTREFHUM", "model_name": {"nb":"Septoria referansefuktmodell", "en":"Septoria reference humidity model"}, "url": "%sSEPTREFHUM" % WMS_SERVER_URL},
    {"model_id":"PSILARTEMP", "model_name": {"nb":"Gulrotflue svermetidspunktmodell", "en":"Carrot rust fly (Psila rosae) temperature model"}, "url": "%sPSILARTEMP" % WMS_SERVER_URL},
    {"model_id":"NAERSTADMO", "model_name": {"nb":"Nærstads modell", "en":"Nærstad's potato blight model"}, "url": "%sNAERSTADMO" % WMS_SERVER_URL}
    ]

# OpenLayers Map (map on front page) initial configuration
# Longitude and latitude in WGS84 format
# See http://en.wikipedia.org/wiki/World_Geodetic_System#A_new_World_Geodetic_System:_WGS_84
MAP_CENTER_LONGITUDE = 14.1
MAP_CENTER_LATITUDE = 65.4
# The zoom level (1-15, 1 is world wide view, 15 is greatest zoom)
MAP_ZOOMLEVEL = 4 
# The height of the map in pixels on the screen
MAP_HEIGHT = 580
# Based on your country/region map, you may want to place the legend 
# where it stays out of the way of your weather stations 
# 1 = top left, 2 = top right, 3 = bottom left, 4 = bottom right
MAP_WARNING_LEGEND_PLACEMENT = 4

# The attribution text that appears in a corner of the map
MAP_ATTRIBUTION = "&copy; <a href='http://www.openstreetmap.org'>OpenStreetMap</a> contributors"

# The message tags to use on the front page
FRONTPAGE_MESSAGE_TAG_IDS = [1,2,3]

# Structure for the main (top) menu. Supports one level of child items,
# which are placed in dropdown menus
# The _() wrapping around labels enables translation
# Sample: 
# MAIN_MENU=[
#    {"url":"/forecasts", "label": _("Forecasts")},
#    {"url":"/messages", "label": _("Messages")},
#    {"label": "Other services", "child_items":[
#        {"url":"/nopage", "label": "Test1"},
#        {"separator": True},
#        {"heading": "Dropdown heading"},
#        {"url":"/nopage", "label": "Test2"},                         
#        ]
#    }
#]
#
MAIN_MENU=[]

# The columns with links below the map
# 12 % Number of columns must be 0 (12 needs to be divisible by number of columns)
FRONTPAGE_MENU=[
    {
        "label": "Cereals and oilseeds", 
        "items":[
                       {"url":"/nopage", "label": "Test1"},
                       {"url":"/nopage", "label": "Test2"},                         
        ]
    },
    {
        "label": "Potato and vegetables",
        "items":[
                       {"url":"/nopage", "label": "Test1"},
                       {"url":"/nopage", "label": "Test2"},                         
        ]
    },
    {    
        "label": "Fruits and berries",
        "items":[
                       {"url":"/nopage", "label": "Test1"},
                       {"url":"/nopage", "label": "Test2"},                         
        ]
    },
    {
        "label": "Other models and services",
        "items":[
                       {"url":"/nopage", "label": "Test1"},
                       {"url":"/nopage", "label": "Test2"},                         
        ]
    }
    
]

# Text and formatting (HTML) for the footer to be
# shown on all web pages. Language code must be specified
# Language selection is as follows:
# 1. The user's selected language
# 2. The default language for the site (Settings.LANGUAGE_CODE)
# 3. English
# 4. The first language in the list of texts
# Example:
# FOOTER HTML = {
#        "en": "VIPS is an automatic forecasting system for agricultural pests and diseases",
#        "nb": "VIPS er et automatisk varslingssystem for skadegjørere i landbruket"
# }
FOOTER_HTML_1= {}

FOOTER_HTML_2= {}

# If set to True, the link to VIPS Mobile (per now a Norwegian only web app)
# will be visible on small screens (like smart phones).
SHOW_VIPS_MOBILE_LINK_ON_SMALL_SCREENS = False

# Settings for the JQueryUI date picker used as a replacement for
# browser's built in date picker when input type="date"
# See JQuery UI docs: https://api.jqueryui.com/datepicker/
DATE_PICKER_CONFIG = { "dateFormat": 'yy-mm-dd', "firstDay": 1 }
